# frozen_string_literal: true

module Gitlab
  module Housekeeper
    class Change
      attr_accessor :identifiers,
        :title,
        :description,
        :changed_files,
        :labels,
        :reviewers

      def initialize
        @labels = []
        @reviewers = []
      end

      def mr_description
        <<~MARKDOWN
        #{description}

        This change was generated by
        [gitlab-housekeeper](https://gitlab.com/gitlab-org/gitlab/-/tree/master/gems/gitlab-housekeeper)
        MARKDOWN
      end

      def commit_message
        <<~MARKDOWN
        #{title}

        #{mr_description}

        Changelog: other
        MARKDOWN
      end

      def matches_filters?(filters)
        filters.all? do |filter|
          identifiers.any? do |identifier|
            identifier.match?(filter)
          end
        end
      end

      def valid?
        @identifiers && @title && @description && @changed_files
      end
    end
  end
end
